==> haskell-storablevector-0.2.13-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-storablevector.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: storablevector
version: 0.2.13
id: storablevector-0.2.13-CDcO8sIPbil4Fpi6LRY9LA
key: storablevector-0.2.13-CDcO8sIPbil4Fpi6LRY9LA
license: BSD3
maintainer: Henning Thielemann <storablevector@henning-thielemann.de>
stability: Experimental
homepage: http://www.haskell.org/haskellwiki/Storable_Vector
synopsis: Fast, packed, strict storable arrays with a list interface like ByteString
description:
    Fast, packed, strict storable arrays
    with a list interface,
    a chunky lazy list interface with variable chunk size
    and an interface for write access via the @ST@ monad.
    This is much like @bytestring@ and @binary@
    but can be used for every '\''Foreign.Storable.Storable'\'' type.
    See also package
    <http://hackage.haskell.org/package/vector>
    with a similar intention.
    .
    We do not provide advanced fusion optimization,
    since especially for lazy vectors
    this would either be incorrect or not applicable.
    However we provide fusion with lazy lists in the package
    <http://hackage.haskell.org/package/storablevector-streamfusion>.
category: Data
author: Spencer Janssen <sjanssen@cse.unl.edu>, Henning Thielemann <storablevector@henning-thielemann.de>
exposed: True
indefinite: False
exposed-modules:
    Data.StorableVector Data.StorableVector.Base
    Data.StorableVector.Lazy Data.StorableVector.Lazy.Builder
    Data.StorableVector.Lazy.Pattern Data.StorableVector.Lazy.Pointer
    Data.StorableVector.Lazy.Typed Data.StorableVector.Pointer
    Data.StorableVector.ST.Lazy Data.StorableVector.ST.Strict
hidden-modules: Data.StorableVector.Memory
                Data.StorableVector.ST.Private
                Data.StorableVector.Lazy.PointerPrivate
                Data.StorableVector.Lazy.PointerPrivateIndex
                Data.StorableVector.Cursor
abi: 5394a54b4c1a82ca5db5d33c5fddcbb4
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/storablevector-0.2.13
library-dirs: /usr/lib/ghc-8.2.2/site-local/storablevector-0.2.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/storablevector-0.2.13
hs-libraries: HSstorablevector-0.2.13-CDcO8sIPbil4Fpi6LRY9LA
depends:
    non-negative-0.1.2-EnVMs9CRf2v55eMNLW3DNx
    utility-ht-0.0.14-1SDJ0BtW7GoAaRrxZT3hIq transformers-0.5.2.0
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q deepseq-1.4.3.0
    unsafe-0.0-BIrI9nXOqv1FDJhoFAi4jR
    QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9 base-4.10.1.0
    syb-0.7-3Lq8MQxmYP07qktjI1jxu0
abi-depends: non-negative-0.1.2-EnVMs9CRf2v55eMNLW3DNx=9a6edebea4d28aece58eef67374bfe46
             utility-ht-0.0.14-1SDJ0BtW7GoAaRrxZT3hIq=0362a121972f0b40c9fe893b813ad252
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             unsafe-0.0-BIrI9nXOqv1FDJhoFAi4jR=7df145c64396018dcd2e7fe561a83a4f
             QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9=77baeaa97e72dac9529ccf150f178180
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             syb-0.7-3Lq8MQxmYP07qktjI1jxu0=f985ea42a9fa578e0f67572a93e19b5d
haddock-interfaces: /usr/share/doc/haskell-storablevector/html/storablevector.haddock
haddock-html: /usr/share/doc/haskell-storablevector/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-storablevector-0.2.13-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-storablevector.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: storablevector
version: 0.2.13
id: storablevector-0.2.13-5JVWXYRmIcV42hbidHPbDP
key: storablevector-0.2.13-5JVWXYRmIcV42hbidHPbDP
license: BSD-3-Clause
maintainer: Henning Thielemann <storablevector@henning-thielemann.de>
author: Spencer Janssen <sjanssen@cse.unl.edu>, Henning Thielemann <storablevector@henning-thielemann.de>
stability: Experimental
homepage: http://www.haskell.org/haskellwiki/Storable_Vector
synopsis: Fast, packed, strict storable arrays with a list interface like ByteString
description:
    Fast, packed, strict storable arrays
    with a list interface,
    a chunky lazy list interface with variable chunk size
    and an interface for write access via the @ST@ monad.
    This is much like @bytestring@ and @binary@
    but can be used for every '\''Foreign.Storable.Storable'\'' type.
    See also package
    <http://hackage.haskell.org/package/vector>
    with a similar intention.
    .
    We do not provide advanced fusion optimization,
    since especially for lazy vectors
    this would either be incorrect or not applicable.
    However we provide fusion with lazy lists in the package
    <http://hackage.haskell.org/package/storablevector-streamfusion>.
category: Data
abi: 76b856dc8835f2a26ef754ce3af7e305
exposed: True
exposed-modules:
    Data.StorableVector Data.StorableVector.Base
    Data.StorableVector.Lazy Data.StorableVector.Lazy.Builder
    Data.StorableVector.Lazy.Pattern Data.StorableVector.Lazy.Pointer
    Data.StorableVector.Lazy.Typed Data.StorableVector.Pointer
    Data.StorableVector.ST.Lazy Data.StorableVector.ST.Strict
hidden-modules: Data.StorableVector.Memory
                Data.StorableVector.ST.Private
                Data.StorableVector.Lazy.PointerPrivate
                Data.StorableVector.Lazy.PointerPrivateIndex
                Data.StorableVector.Cursor
import-dirs: /usr/lib/ghc-8.4.3/site-local/storablevector-0.2.13
library-dirs: /usr/lib/ghc-8.4.3/site-local/storablevector-0.2.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/storablevector-0.2.13
hs-libraries: HSstorablevector-0.2.13-5JVWXYRmIcV42hbidHPbDP
depends:
    non-negative-0.1.2-CzJkHCeQuFC7hHKT455tko
    utility-ht-0.0.14-CqclJgoUReM5xZSC1dChOW transformers-0.5.5.0
    deepseq-1.4.3.0 unsafe-0.0-GMfN8SJyoiBOcfugVwnQq
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr base-4.11.1.0
    syb-0.7-2jW43lwzJV5e7EQvU8PxV
abi-depends: non-negative-0.1.2-CzJkHCeQuFC7hHKT455tko=e7efeca0bd431e2db49175a2941bd22c
             utility-ht-0.0.14-CqclJgoUReM5xZSC1dChOW=632b3d47f82599a1155bed59f183b750
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             unsafe-0.0-GMfN8SJyoiBOcfugVwnQq=a397e4371ccccc2e517eaf2a44e24dc0
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             syb-0.7-2jW43lwzJV5e7EQvU8PxV=867165047495b4e6f144c8b9b108f918
haddock-interfaces: /usr/share/doc/haskell-storablevector/html/storablevector.haddock
haddock-html: /usr/share/doc/haskell-storablevector/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
